@@ -13,14 +13,6 @@
  * Alphabetical list of all possible commands.
  */
 
-#define CONFIG_CMD_BEDBUG	/* Include BedBug Debugger	*/
-#define CONFIG_CMD_BMP		/* BMP support			*/
-#define CONFIG_CMD_BSP		/* Board Specific functions	*/
-#define CONFIG_CMD_CLK		/* Clock support		*/
-#define CONFIG_CMD_DATE		/* support for RTC, date/time...*/
-#define CONFIG_CMD_DIAG		/* Diagnostics			*/
-#define CONFIG_CMD_DISPLAY	/* Display support		*/
-#define CONFIG_CMD_DOC		/* Disk-On-Chip Support		*/
 #define CONFIG_CMD_DTT		/* Digital Therm and Thermostat */
 #define CONFIG_CMD_EEPROM	/* EEPROM read/write support	*/
 #define CONFIG_CMD_FDC		/* Floppy Disk Support		*/
@@ -48,10 +40,8 @@
 #define CONFIG_SCSI		/* SCSI Support			*/
 #define CONFIG_CMD_SDRAM	/* SDRAM DIMM SPD info printout */
 #define CONFIG_CMD_TERMINAL	/* built-in Serial Terminal	*/
-#define CONFIG_CMD_UBI		/* UBI Support			*/
 #define CONFIG_CMD_UBIFS	/* UBIFS Support		*/
 #define CONFIG_CMD_UNIVERSE	/* Tundra Universe Support	*/
-#define CONFIG_CMD_UNZIP	/* unzip from memory to memory	*/
 #define CONFIG_CMD_ZFS		/* ZFS Support			*/
 
 #endif	/* _CONFIG_CMD_ALL_H */
