@@ -21,13 +21,11 @@
 
 #define CONFIG_MCFUART
 #define CONFIG_SYS_UART_PORT		(0)
-#define CONFIG_BAUDRATE		115200
 
 #undef CONFIG_WATCHDOG
 #define CONFIG_WATCHDOG_TIMEOUT	5000	/* timeout in milliseconds, max timeout is 6.71sec */
 
 /* Command line configuration */
-#define CONFIG_CMD_DATE
 #define CONFIG_CMD_REGINFO
 
 #ifdef CONFIG_NANDFLASH_SIZE
