@@ -47,7 +47,6 @@
 /*
  * Serial Console Configuration
  */
-#define	CONFIG_BAUDRATE			115200
 
 /*
  * Bootloader Components Configuration
@@ -66,8 +65,6 @@
 #ifdef CONFIG_LCD
 #define CONFIG_PXA_LCD
 #define CONFIG_PXA_VGA
-#define CONFIG_SYS_WHITE_ON_BLACK
-#define CONFIG_CMD_BMP
 #define CONFIG_LCD_LOGO
 #endif
 
