@@ -54,7 +54,6 @@
 /* allow to overwrite serial and ethaddr */
 #define CONFIG_ENV_OVERWRITE
 #define CONFIG_CONS_INDEX       1
-#define CONFIG_BAUDRATE         115200
 
 /* Filesystems and image support */
 #define CONFIG_SUPPORT_RAW_INITRD
@@ -85,7 +84,6 @@
 /* Secure boot (HAB) support */
 #ifdef CONFIG_SECURE_BOOT
 #define CONFIG_CSF_SIZE			0x2000
-#define CONFIG_CMD_DEKBLOB
 #ifdef CONFIG_SPL_BUILD
 #define CONFIG_SPL_DRIVERS_MISC_SUPPORT
 #endif
