@@ -13,10 +13,9 @@
 #define _CONFIG_NAS220_H
 
 /*
- * Machine type definition and ID
+ * Machine type ID
  */
-#define MACH_TYPE_NAS220		MACH_TYPE_RD88F6192_NAS
-#define CONFIG_MACH_TYPE		MACH_TYPE_NAS220
+#define CONFIG_MACH_TYPE		MACH_TYPE_RD88F6192_NAS
 
 /*
  * High Level Configuration Options (easy to change)
@@ -42,9 +41,7 @@
 /*
  * Commands configuration
  */
-#define CONFIG_SYS_NO_FLASH		/* Declare no flash (NOR/SPI) */
 #define CONFIG_CMD_NAND
-#define CONFIG_CMD_DATE
 #define CONFIG_CMD_IDE
 #define CONFIG_SYS_LONGHELP
 #define CONFIG_AUTO_COMPLETE
@@ -100,7 +97,6 @@
 #define CONFIG_USB_EHCI			/* Enable EHCI USB support */
 #define CONFIG_USB_EHCI_KIRKWOOD	/* on Kirkwood platform	*/
 #define CONFIG_EHCI_IS_TDI
-#define CONFIG_DOS_PARTITION
 #define CONFIG_SUPPORT_VFAT
 #endif /* CONFIG_CMD_USB */
 
@@ -128,7 +124,6 @@
 /*
  * EFI partition
  */
-#define CONFIG_EFI_PARTITION
 
 /*
  *  Date Time
