@@ -36,7 +36,6 @@
 #define CONFIG_PANIC_HANG	/* do not reset board on panic */
 
 /* Needed to fill the ccsrbar pointer */
-#define CONFIG_BOARD_EARLY_INIT_F
 
 /* Virtual address to CCSRBAR */
 #define CONFIG_SYS_CCSRBAR		0xe0000000
@@ -68,8 +67,6 @@ extern unsigned long long get_phys_ccsrbar_addr_early(void);
 
 #define CONFIG_SYS_CLK_FREQ        33000000
 
-#define CONFIG_SYS_NO_FLASH
-
 #define CONFIG_SYS_BOOT_BLOCK		0x00000000	/* boot TLB */
 
 #define CONFIG_SYS_MONITOR_BASE		CONFIG_SYS_TEXT_BASE
@@ -114,11 +111,9 @@ extern unsigned long long get_phys_ccsrbar_addr_early(void);
 #define CONFIG_PCI_INDIRECT_BRIDGE
 
 #define CONFIG_PCI_SCAN_SHOW		/* show pci devices on startup */
-#define CONFIG_DOS_PARTITION
 #endif	/* CONFIG_PCI */
 
 #define CONFIG_LBA48
-#define CONFIG_DOS_PARTITION
 
 /*
  * Environment
@@ -168,8 +163,6 @@ extern unsigned long long get_phys_ccsrbar_addr_early(void);
 /* default location for tftp and bootm */
 #define CONFIG_LOADADDR		1000000
 
-#define CONFIG_BAUDRATE	115200
-
 #define CONFIG_BOOTCOMMAND		\
 	"test -n \"$qemu_kernel_addr\" && bootm $qemu_kernel_addr - $fdt_addr_r\0"
 
