@@ -12,12 +12,9 @@
 #include "mx6_common.h"
 
 /* General configuration */
-#define CONFIG_SYS_THUMB_BUILD
 
 #define CONFIG_MACH_TYPE		3980
 
-#define CONFIG_BOARD_EARLY_INIT_F
-
 #define CONFIG_SYS_HZ			1000
 
 #define CONFIG_IMX_THERMAL
@@ -44,17 +41,10 @@
 /* Serial console */
 #define CONFIG_MXC_UART
 #define CONFIG_MXC_UART_BASE		UART1_BASE /* select UART1/UART2 */
-#define CONFIG_BAUDRATE			115200
 
 #define CONFIG_CONS_INDEX		1
 
-/* *** Command definition *** */
-#define CONFIG_CMD_BMODE
-#define CONFIG_CMD_PART
-
 /* Filesystems / image support */
-#define CONFIG_EFI_PARTITION
-#define CONFIG_PARTITION_UUIDS
 
 /* MMC */
 #define CONFIG_SYS_FSL_USDHC_NUM	3
@@ -125,7 +115,6 @@
 #endif /* CONFIG_CMD_USB      */
 
 /* RTC */
-#define CONFIG_CMD_DATE
 #ifdef CONFIG_CMD_DATE
 #define CONFIG_RTC_DS1307
 #define CONFIG_SYS_RTC_BUS_NUM		2
